import {compile} from "../compiler.js";

var tests = [
  ["decoration-slice", {"box-decoration-break": "slice", "-webkit-box-decoration-break": "slice"}],
  ["decoration-clone", {"box-decoration-break": "clone", "-webkit-box-decoration-break": "clone"}],
  ["decoration-xxx", {"box-decoration-break": "xxx", "-webkit-box-decoration-break": "xxx"}],
  ["decoration-", false],
  ["decoration", false],
  ["box-border", {"box-sizing": "border-box"}],
  ["box-content", {"box-sizing": "content-box"}],
  ["box-xxx", {"box-sizing": "xxx-box"}],
  ["inline-block", {"display": "inline-block"}],
  ["inline",  {"display": "inline"}],
  ["flex",  {"display": "flex"}],
  ["inline-flex", {"display": "inline-flex"}],
  ["table", {"display": "table"}],
  ["inline-table", {"display": "inline-table"}],
  ["table-caption", {"display": "table-caption"}],
  ["table-cell", {"display": "table-cell"}],
  ["table-column", {"display": "table-column"}],
  ["table-column-group", {"display": "table-column-group"}],
  ["table-footer-group", {"display": "table-footer-group"}],
  ["table-header-group", {"display": "table-header-group"}],
  ["table-row-group", {"display": "table-row-group"}],
  ["table-row", {"display": "table-row"}],
  ["flow-root", {"display": "flow-root"}],
  ["grid", {"display": "grid"}],
  ["inline-grid", {"display": "inline-grid"}],
  ["contents", {"display": "contents"}],
  ["list-item", {"display": "list-item"}],
  ["hidden",  {"display": "none"}],
  ["float-right", {"float": "right"}],
  ["float-left",  {"float": "left"}],
  ["float-none",  {"float": "none"}],
  ["clear-left",  {"clear": "left"}],
  ["clear-right", {"clear": "right"}],
  ["clear-both", {"clear": "both"}],
  ["clear-none",  {"clear": "none"}],
  ["isolate", {"isolation": "isolate"}],
  ["isolation-auto", {"isolation": "auto"}],
  ["object-contain",  {"object-fit": "contain"}],
  ["object-cover",  {"object-fit": "cover"}],
  ["object-fill", {"object-fit": "fill"}],
  ["object-none", {"object-fit": "none"}],
  ["object-scale-down", {"object-fit": "scale-down"}],
  ["object-bottom", {"object-position": "bottom"}],
  ["object-center", {"object-position": "center"}],
  ["object-left", {"object-position": "left"}],
  ["object-left-bottom", {"object-position": "left bottom"}],
  ["object-left-top", {"object-position": "left top"}],
  ["object-right", {"object-position": "right"}],
  ["object-right-bottom", {"object-position": "right bottom"}],
  ["object-right-top", {"object-position": "right top"}],
  ["object-top", {"object-position": "top"}],
  ["overflow-auto", {"overflow": "auto"}],
  ["overflow-hidden", {"overflow": "hidden"}],
  ["overflow-visible",  {"overflow": "visible"}],
  ["overflow-scroll", {"overflow": "scroll"}],
  ["overflow-x-auto", {"overflow-x": "auto"}],
  ["overflow-y-auto", {"overflow-y": "auto"}],
  ["overflow-x-hidden", {"overflow-x": "hidden"}],
  ["overflow-y-hidden", {"overflow-y": "hidden"}],
  ["overflow-x-visible", {"overflow-x": "visible"}],
  ["overflow-y-visible", {"overflow-y": "visible"}],
  ["overflow-x-scroll", {"overflow-x": "scroll"}],
  ["overflow-y-scroll", {"overflow-y": "scroll"}],
  ["overscroll-auto", {"overscroll-behavior": "auto"}],
  ["overscroll-contain", {"overscroll-behavior": "contain"}],
  ["overscroll-none", {"overscroll-behavior": "none"}],
  ["overscroll-y-auto", {"overscroll-behavior-y": "auto"}],
  ["overscroll-y-contain", {"overscroll-behavior-y": "contain"}],
  ["overscroll-y-none", {"overscroll-behavior-y": "none"}],
  ["overscroll-x-auto", {"overscroll-behavior-x": "auto"}],
  ["overscroll-x-contain", {"overscroll-behavior-x": "contain"}],
  ["overscroll-x-none", {"overscroll-behavior-x": "none"}],
  ["static", {"position": "static"}],
  ["fixed", {"position": "fixed"}],
  ["absolute", {"position": "absolute"}],
  ["relative", {"position": "relative"}],
  ["sticky",  {"position": "sticky"}],
  ["visible", {"visibility": "visible"}],
  ["invisible", {"visibility": "hidden"}],
  ["z-0", {"z-index": "0"}],
  ["z-10",  {"z-index": "10"}],
  ["z-auto",  {"z-index": "auto"}],
  ["z-1000",  {"z-index": "1000"}],
  
  ["inset-auto", {"top": "auto", "right": "auto", "bottom": "auto", "left": "auto"}],
  ["-inset-auto", {"top": "auto", "right": "auto", "bottom": "auto", "left": "auto"}],
  ["inset-0", {"top": "0", "right": "0", "bottom": "0", "left": "0"}],
  ["inset-px", {"top": "1px", "right": "1px", "bottom": "1px", "left": "1px"}],
  ["-inset-0", {"top": "0", "right": "0", "bottom": "0", "left": "0"}],
  ["-inset-px", {"top": "-1px", "right": "-1px", "bottom": "-1px", "left": "-1px"}],
  ["inset-1", {"top": "0.25rem", "right": "0.25rem", "bottom": "0.25rem", "left": "0.25rem"}],
  ["-inset-1", {"top": "-0.25rem", "right": "-0.25rem", "bottom": "-0.25rem", "left": "-0.25rem"}],
  ["inset-1/2", {"top": "50%", "right": "50%", "bottom": "50%", "left": "50%"}],
  ["-inset-1/2", {"top": "-50%", "right": "-50%", "bottom": "-50%", "left": "-50%"}],
  ["inset-full", {"top": "100%", "right": "100%", "bottom": "100%", "left": "100%"}],
  ["-inset-full", {"top": "-100%", "right": "-100%", "bottom": "-100%", "left": "-100%"}],
  ["inset-9/10", {"top": "90%", "right": "90%", "bottom": "90%", "left": "90%"}],

  ["inset-x-auto", {"right": "auto", "left": "auto"}],
  ["-inset-x-auto", {"right": "auto", "left": "auto"}],
  ["inset-x-0", {"right": "0", "left": "0"}],
  ["inset-x-px", {"right": "1px", "left": "1px"}],
  ["-inset-x-0", {"right": "0", "left": "0"}],
  ["-inset-x-px", {"right": "-1px", "left": "-1px"}],
  ["inset-x-1", {"right": "0.25rem", "left": "0.25rem"}],
  ["-inset-x-1", {"right": "-0.25rem", "left": "-0.25rem"}],
  ["inset-x-1/2", {"right": "50%", "left": "50%"}],
  ["-inset-x-1/2", {"right": "-50%", "left": "-50%"}],
  ["inset-x-full", {"right": "100%", "left": "100%"}],
  ["-inset-x-full", {"right": "-100%", "left": "-100%"}],

  ["inset-y-auto", {"top": "auto", "bottom": "auto"}],
  ["-inset-y-auto", {"top": "auto", "bottom": "auto"}],
  ["inset-y-0", {"top": "0", "bottom": "0"}],
  ["inset-y-px", {"top": "1px", "bottom": "1px"}],
  ["-inset-y-0", {"top": "0", "bottom": "0"}],
  ["-inset-y-px", {"top": "-1px", "bottom": "-1px"}],
  ["inset-y-1", {"top": "0.25rem", "bottom": "0.25rem"}],
  ["-inset-y-1", {"top": "-0.25rem", "bottom": "-0.25rem"}],
  ["inset-y-1/2", {"top": "50%", "bottom": "50%"}],
  ["-inset-y-1/2", {"top": "-50%", "bottom": "-50%"}],
  ["inset-y-full", {"top": "100%", "bottom": "100%"}],
  ["-inset-y-full", {"top": "-100%", "bottom": "-100%"}],

  ["top-auto", {"top": "auto"}],
  ["-top-auto", {"top": "auto"}],
  ["top-0", {"top": "0"}],
  ["top-px", {"top": "1px"}],
  ["-top-0", {"top": "0"}],
  ["-top-px", {"top": "-1px"}],
  ["top-1", {"top": "0.25rem"}],
  ["-top-1", {"top": "-0.25rem"}],
  ["top-1/2", {"top": "50%"}],
  ["-top-1/2", {"top": "-50%"}],
  ["top-full", {"top": "100%"}],
  ["-top-full", {"top": "-100%"}],

  ["bottom-auto", {"bottom": "auto"}],
  ["-bottom-auto", {"bottom": "auto"}],
  ["bottom-0", {"bottom": "0"}],
  ["bottom-px", {"bottom": "1px"}],
  ["-bottom-0", {"bottom": "0"}],
  ["-bottom-px", {"bottom": "-1px"}],
  ["bottom-1", {"bottom": "0.25rem"}],
  ["-bottom-1", {"bottom": "-0.25rem"}],
  ["bottom-1/2", {"bottom": "50%"}],
  ["-bottom-1/2", {"bottom": "-50%"}],
  ["bottom-full", {"bottom": "100%"}],
  ["-bottom-full", {"bottom": "-100%"}],

  ["left-1", {"left": "0.25rem"}],
  ["right-1", {"right": "0.25rem"}],

  ["flex-row", {"flex-direction": "row"}],
  ["flex-row-reverse", {"flex-direction": "row-reverse"}],
  ["flex-col", {"flex-direction": "column"}],
  ["flex-col-reverse", {"flex-direction": "column-reverse"}],

  ["flex-wrap", {"flex-wrap": "wrap"}], 
  ["flex-wrap-reverse", {"flex-wrap": "wrap-reverse"}],
  ["flex-nowrap", {"flex-wrap": "nowrap"}],

  ["flex-1", {"flex": "1 1 0%"}],
  ["flex-auto", {"flex": "1 1 auto"}],
  ["flex-initial", {"flex": "0 1 auto"}],
  ["flex-none", {"flex": "none"}],

  ["flex-grow-0", {"flex-grow": "0"}],
  ["flex-grow", {"flex-grow": "1"}],
  ["flex-shrink-0", {"flex-shrink": "0"}],
  ["flex-shrink", {"flex-shrink": "1"}],

  ["order-12",  {"order": "12"}],
  ["order-first", {"order": "-9999"}],
  ["order-last",  {"order": "9999"}],
  ["order-none",  {"order": "0"}],

  ["grid-cols-12", {"grid-template-columns": "repeat(12, minmax(0, 1fr))"}],
  ["grid-cols-none", {"grid-template-columns": "none"}],
  ["grid-cols-21", {"grid-template-columns": "repeat(21, minmax(0, 1fr))"}],

  ["grid-rows-12", {"grid-template-rows": "repeat(12, minmax(0, 1fr))"}],
  ["grid-rows-none", {"grid-template-rows": "none"}],
  ["grid-rows-21", {"grid-template-rows": "repeat(21, minmax(0, 1fr))"}],

  ["col-auto", {"grid-column": "auto"}],
  ["col-span-1", {"grid-column": "span 1 / span 1"}],
  ["col-span-full", {"grid-column": "1 / -1"}],
  ["col-start-2", {"grid-column-start": "2"}],
  ["col-start-auto", {"grid-column-start": "auto"}],
  ["col-end-2", {"grid-column-end": "2"}],
  ["col-end-auto", {"grid-column-end": "auto"}],

  ["row-auto", {"grid-row": "auto"}],
  ["row-span-1", {"grid-row": "span 1 / span 1"}],
  ["row-span-full", {"grid-row": "1 / -1"}],
  ["row-start-2", {"grid-row-start": "2"}],
  ["row-start-auto", {"grid-row-start": "auto"}],
  ["row-end-2", {"grid-row-end": "2"}],
  ["row-end-auto", {"grid-row-end": "auto"}],

  ["grid-flow-row", {"grid-auto-flow": "row"}],
  ["grid-flow-col", {"grid-auto-flow": "column"}],
  ["grid-flow-row-dense", {"grid-auto-flow": "row dense"}],
  ["grid-flow-col-dense", {"grid-auto-flow": "column dense"}],

  ["auto-cols-auto", {"grid-auto-columns": "auto"}],
  ["auto-cols-min", {"grid-auto-columns": "min-content"}],
  ["auto-cols-max", {"grid-auto-columns": "max-content"}],
  ["auto-cols-fr",  {"grid-auto-columns": "minmax(0, 1fr)"}],

  ["auto-rows-auto", {"grid-auto-rows": "auto"}],
  ["auto-rows-min", {"grid-auto-rows": "min-content"}],
  ["auto-rows-max", {"grid-auto-rows": "max-content"}],
  ["auto-rows-fr",  {"grid-auto-rows": "minmax(0, 1fr)"}],

  ["items-start", {"align-items": "flex-start"}],
  ["items-end", {"align-items": "flex-end"}],
  ["items-center", {"align-items": "center"}],
  ["items-baseline", {"align-items": "baseline"}],
  ["items-stretch", {"align-items": "stretch"}],

  ["gap-0", {"gap": "0"}],
  ["gap-x-0", {"column-gap": "0"}],
  ["gap-y-0", {"row-gap": "0"}],
  ["gap-4", {"gap": "1rem"}],
  ["gap-x-4", {"column-gap": "1rem"}],
  ["gap-y-4", {"row-gap": "1rem"}],

  ["justify-start", {"justify-content": "flex-start"}],
  ["justify-end", {"justify-content": "flex-end"}],
  ["justify-center",  {"justify-content": "center"}],
  ["justify-between", {"justify-content": "space-between"}],
  ["justify-around",  {"justify-content": "space-around"}],
  ["justify-evenly",  {"justify-content": "space-evenly"}],

  ["justify-items-start", {"justify-items": "start"}],    
  ["justify-items-end", {"justify-items": "end"}],
  ["justify-items-center",  {"justify-items": "center"}],
  ["justify-items-stretch", {"justify-items": "stretch"}],

  ["justify-self-auto", {"justify-self": "auto"}],
  ["justify-self-start", {"justify-self": "start"}],
  ["justify-self-end",  {"justify-self": "end"}],
  ["justify-self-center", {"justify-self": "center"}],
  ["justify-self-stretch", {"justify-self": "stretch"}],

  ["content-center",  {"align-content": "center"}],
  ["content-start", {"align-content": "flex-start"}],
  ["content-end", {"align-content": "flex-end"}],
  ["content-between", {"align-content": "space-between"}],
  ["content-around", {"align-content": "space-around"}],
  ["content-evenly", {"align-content": "space-evenly"}],

  ["items-start", {"align-items": "flex-start"}],
  ["items-end", {"align-items": "flex-end"}],
  ["items-center", {"align-items": "center"}],
  ["items-baseline", {"align-items": "baseline"}],
  ["items-stretch", {"align-items": "stretch"}],

  ["self-auto", {"align-self": "auto"}],
  ["self-start", {"align-self": "flex-start"}],
  ["self-end", {"align-self": "flex-end"}],
  ["self-center", {"align-self": "center"}],
  ["self-stretch", {"align-self": "stretch"}],

  ["place-content-center", {"place-content": "center"}],
  ["place-content-start", {"place-content": "start"}],
  ["place-content-end", {"place-content": "end"}],
  ["place-content-between", {"place-content": "space-between"}],
  ["place-content-around",  {"place-content": "space-around"}],
  ["place-content-evenly", {"place-content": "space-evenly"}],
  ["place-content-stretch", {"place-content": "stretch"}],

  ["place-items-start", {"place-items": "start"}],
  ["place-items-end", {"place-items": "end"}],
  ["place-items-center", {"place-items": "center"}],
  ["place-items-stretch", {"place-items": "stretch"}],

  ["place-self-auto", {"place-self": "auto"}],
  ["place-self-start",  {"place-self": "start"}],
  ["place-self-end",  {"place-self": "end"}],
  ["place-self-center", {"place-self": "center"}],
  ["place-self-stretch",  {"place-self": "stretch"}],

  ["p-0", {"padding": "0"}],
  ["px-0", {"padding-left": "0", "padding-right": "0"}],
  ["py-0", {"padding-top": "0", "padding-bottom": "0"}],
  ["pt-0", {"padding-top": "0"}],
  ["pb-0", {"padding-bottom": "0"}],
  ["pl-0", {"padding-left": "0"}],
  ["pr-0", {"padding-right": "0"}],
  ["p-96", {"padding": "24rem"}],
  ["px-96", {"padding-left": "24rem", "padding-right": "24rem"}],
  ["py-96", {"padding-top": "24rem", "padding-bottom": "24rem"}],
  ["pt-96", {"padding-top": "24rem"}],
  ["pb-96", {"padding-bottom": "24rem"}],
  ["pl-96", {"padding-left": "24rem"}],
  ["pr-96", {"padding-right": "24rem"}],

  ["m-0", {"margin": "0"}],
  ["-m-0", {"margin": "0"}],
  ["mx-0", {"margin-left": "0", "margin-right": "0"}],
  ["my-0", {"margin-top": "0", "margin-bottom": "0"}],
  ["mt-0", {"margin-top": "0"}],
  ["mb-0", {"margin-bottom": "0"}],
  ["ml-0", {"margin-left": "0"}],
  ["mr-0", {"margin-right": "0"}],
  ["m-96", {"margin": "24rem"}],
  ["mx-96", {"margin-left": "24rem", "margin-right": "24rem"}],
  ["my-96", {"margin-top": "24rem", "margin-bottom": "24rem"}],
  ["mt-96", {"margin-top": "24rem"}],
  ["mb-96", {"margin-bottom": "24rem"}],
  ["ml-96", {"margin-left": "24rem"}],
  ["mr-96", {"margin-right": "24rem"}],
  ["-m-96", {"margin": "-24rem"}],
  ["-mx-96", {"margin-left": "-24rem", "margin-right": "-24rem"}],
  ["-my-96", {"margin-top": "-24rem", "margin-bottom": "-24rem"}],
  ["-mt-96", {"margin-top": "-24rem"}],
  ["-mb-96", {"margin-bottom": "-24rem"}],
  ["-ml-96", {"margin-left": "-24rem"}],
  ["-mr-96", {"margin-right": "-24rem"}],

  ["space-x-1", {"--tw-space-x-reverse": "0", "margin-right": "calc(0.25rem * var(--tw-space-x-reverse))",
                  "margin-left": "calc(0.25rem * calc(1 - var(--tw-space-x-reverse)))"}],
  ["space-x-reverse", {"--tw-space-x-reverse": "1"}], 
  ["space-y-1", {"--tw-space-y-reverse": "0", "margin-top": "calc(0.25rem * calc(1 - var(--tw-space-y-reverse)))",
                  "margin-bottom": "calc(0.25rem * var(--tw-space-y-reverse))"}],
  ["space-y-reverse", {"--tw-space-y-reverse": "1"}], 

  ["w-5", {"width": "1.25rem"}],
  ["w-auto", {"width": "auto"}],
  ["w-1/3", {"width": "33.33333333333333%"}],
  ["w-full", {"width": "100%"}],
  ["w-screen", {"width": "100vw"}],
  ["w-min", {"width": "min-content"}],
  ["w-max", {"width": "max-content"}],

  ["h-5", {"height": "1.25rem"}],
  ["h-auto", {"height": "auto"}],
  ["h-1/3", {"height": "33.33333333333333%"}],
  ["h-full", {"height": "100%"}],
  ["h-screen", {"height": "100vh"}],

  ["min-w-0", {"min-width": "0"}],
  ["min-w-full", {"min-width": "100%"}],
  ["min-w-min", {"min-width": "min-content"}],
  ["min-w-max", {"min-width": "max-content"}],
  ["min-h-0", {"min-height": "0"}],
  ["min-h-full", {"min-height": "100%"}],
  ["min-h-screen", {"min-height": "100vh"}],

  ["max-w-0", {"max-width": "0rem"}],
  ["max-w-none", {"max-width": "none"}],
  ["max-w-xs", {"max-width": "20rem"}],
  ["max-w-sm", {"max-width": "24rem"}],
  ["max-w-md", {"max-width": "28rem"}],
  ["max-w-lg", {"max-width": "32rem"}],
  ["max-w-xl", {"max-width": "36rem"}],
  ["max-w-2xl", {"max-width": "42rem"}],
  ["max-w-3xl", {"max-width": "48rem"}],
  ["max-w-4xl", {"max-width": "56rem"}],
  ["max-w-5xl", {"max-width": "64rem"}],
  ["max-w-6xl", {"max-width": "72rem"}],
  ["max-w-7xl", {"max-width": "80rem"}],
  ["max-w-full",  {"max-width": "100%"}],
  ["max-w-min", {"max-width": "min-content"}],
  ["max-w-max", {"max-width": "max-content"}],
  ["max-w-prose", {"max-width": "65ch"}],
  ["max-w-screen-sm", {"max-width": "640px"}],
  ["max-w-screen-md", {"max-width": "768px"}],
  ["max-w-screen-lg", {"max-width": "1024px"}],
  ["max-w-screen-xl", {"max-width": "1280px"}],
  ["max-w-screen-2xl", {"max-width": "1536px"}],

  ["max-h-4", {"max-height": "1rem"}],
  ["max-h-full", {"max-height": "100%"}],
  ["max-h-screen", {"max-height": "100vh"}],

  ["font-sans", {"font-family": 'ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji"'}],
  ["font-serif", {"font-family": 'ui-serif, Georgia, Cambria, "Times New Roman", Times, serif'}],
  ["font-mono", {"font-family": 'ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace'}],

  ["text-xs", {"font-size": "0.75rem", "line-height": "1rem"}],
  ["text-sm", {"font-size": "0.875rem", "line-height": "1.25rem"}],
  ["text-base", {"font-size": "1rem", "line-height": "1.5rem"}],
  ["text-lg", {"font-size": "1.125rem", "line-height": "1.75rem"}],
  ["text-xl", {"font-size": "1.25rem", "line-height": "1.75rem"}],
  ["text-2xl", {"font-size": "1.5rem", "line-height": "2rem"}],
  ["text-3xl", {"font-size": "1.875rem", "line-height": "2.25rem"}],
  ["text-4xl", {"font-size": "2.25rem", "line-height": "2.5rem"}],
  ["text-5xl", {"font-size": "3rem", "line-height": "1"}],
  ["text-6xl", {"font-size": "3.75rem", "line-height": "1"}],
  ["text-7xl", {"font-size": "4.5rem", "line-height": "1"}],
  ["text-8xl", {"font-size": "6rem", "line-height": "1"}],
  ["text-9xl", {"font-size": "8rem", "line-height": "1"}],

  ["antialiased", {"-webkit-font-smoothing": "antialiased", "-moz-osx-font-smoothing": "grayscale"}],
  ["subpixel-antialiased", {"-webkit-font-smoothing": "auto", "-moz-osx-font-smoothing": "auto"}],

  ["italic", {"font-style": "italic"}],
  ["not-italic", {"font-style": "normal"}],

  ["font-thin", {"font-weight": "100"}],
  ["font-extralight", {"font-weight": "200"}],
  ["font-light",  {"font-weight": "300"}],
  ["font-normal", {"font-weight": "400"}],
  ["font-medium", {"font-weight": "500"}],
  ["font-semibold", {"font-weight": "600"}],
  ["font-bold", {"font-weight": "700"}],
  ["font-extrabold", {"font-weight": "800"}],
  ["font-black", {"font-weight": "900"}],

  ["normal-nums", {"font-variant-numeric": "normal"}],
  ["ordinal", {"font-variant-numeric": "ordinal"}],
  ["slashed-zero", {"font-variant-numeric": "slashed-zero"}],
  ["lining-nums", {"font-variant-numeric": "lining-nums"}],
  ["oldstyle-nums", {"font-variant-numeric": "oldstyle-nums"}],
  ["proportional-nums", {"font-variant-numeric": "proportional-nums"}],
  ["tabular-nums", {"font-variant-numeric": "tabular-nums"}],
  ["diagonal-fractions", {"font-variant-numeric": "diagonal-fractions"}],
  ["stacked-fractions", {"font-variant-numeric": "stacked-fractions"}],

  ["tracking-tighter",  {"letter-spacing": "-0.05em"}],
  ["tracking-tight",  {"letter-spacing": "-0.025em"}],
  ["tracking-normal", {"letter-spacing": "0em"}],
  ["tracking-wide", {"letter-spacing": "0.025em"}],
  ["tracking-wider",  {"letter-spacing": "0.05em"}],
  ["tracking-widest", {"letter-spacing": "0.1em"}],

  ["leading-3", {"line-height": ".75rem"}],
  ["leading-4", {"line-height": "1rem"}],
  ["leading-5", {"line-height": "1.25rem"}],
  ["leading-6", {"line-height": "1.5rem"}],
  ["leading-7", {"line-height": "1.75rem"}],
  ["leading-8", {"line-height": "2rem"}],
  ["leading-9", {"line-height": "2.25rem"}],
  ["leading-10", {"line-height": "2.5rem"}],
  ["leading-none", {"line-height": "1"}],
  ["leading-tight", {"line-height": "1.25"}],
  ["leading-snug", {"line-height": "1.375"}],
  ["leading-normal", {"line-height": "1.5"}],
  ["leading-relaxed", {"line-height": "1.625"}],
  ["leading-loose", {"line-height": "2"}],

  ["list-none", {"list-style-type": "none"}],
  ["list-disc", {"list-style-type": "disc"}],
  ["list-decimal", {"list-style-type": "decimal"}],

  ["list-inside", {"list-style-position": "inside"}],
  ["list-outside", {"list-style-position": "outside"}],

  ["placeholder-transparent", {"color": "transparent", "_pelem": "placeholder"}],
  ["placeholder-current", {"color": "currentColor", "_pelem": "placeholder"}],
  ["placeholder-red-100", {"--tw-placeholder-opacity": "1", "_pelem": "placeholder", 
    "color": "rgba(254,226,226,var(--tw-placeholder-opacity))"}],

  ["placeholder-opacity-0", {"--tw-placeholder-opacity": "0"}],
  ["placeholder-opacity-5", {"--tw-placeholder-opacity": "0.05"}],
  ["placeholder-opacity-10",  {"--tw-placeholder-opacity": "0.1"}],

  ["text-left", {"text-align": "left"}],
  ["text-center", {"text-align": "center"}],
  ["text-right",  {"text-align": "right"}],
  ["text-justify",  {"text-align": "justify"}],

  ["text-transparent", {"color": "transparent"}],
  ["text-current", {"color": "currentColor"}],
  ["text-purple-900", {"--tw-text-opacity": "1", "color": "rgba(76,29,149,var(--tw-text-opacity))"}],

  ["text-opacity-0", {"--tw-text-opacity": "0"}],
  ["text-opacity-5", {"--tw-text-opacity": "0.05"}],
  ["text-opacity-10",  {"--tw-text-opacity": "0.1"}],

  ["underline", {"text-decoration": "underline"}],
  ["line-through", {"text-decoration": "line-through"}],
  ["no-underline",  {"text-decoration": "none"}],

  ["uppercase", {"text-transform": "uppercase"}],
  ["lowercase", {"text-transform": "lowercase"}],
  ["capitalize", {"text-transform": "capitalize"}],
  ["normal-case", {"text-transform": "none"}],

  ["truncate", {"overflow": "hidden", "text-overflow": "ellipsis", "white-space": "nowrap"}],
  ["overflow-ellipsis", {"text-overflow": "ellipsis"}],
  ["overflow-clip", {"text-overflow": "clip"}],

  ["align-baseline", {"vertical-align": "baseline"}],
  ["align-top", {"vertical-align": "top"}],
  ["align-middle", {"vertical-align": "middle"}],
  ["align-bottom", {"vertical-align": "bottom"}],
  ["align-text-top", {"vertical-align": "text-top"}],
  ["align-text-bottom", {"vertical-align": "text-bottom"}],

  ["whitespace-normal", {"white-space": "normal"}],
  ["whitespace-nowrap", {"white-space": "nowrap"}],
  ["whitespace-pre",  {"white-space": "pre"}],
  ["whitespace-pre-line", {"white-space": "pre-line"}],
  ["whitespace-pre-wrap", {"white-space": "pre-wrap"}],

  ["break-normal", {"overflow-wrap": "normal", "word-break": "normal"}],
  ["break-words", {"overflow-wrap": "break-word"}],
  ["break-all", {"word-break": "break-all"}],

  ["bg-fixed", {"background-attachment": "fixed"}],
  ["bg-local", {"background-attachment": "local"}],
  ["bg-scroll", {"background-attachment": "scroll"}],

  ["bg-clip-border", {"background-clip": "border-box"}],
  ["bg-clip-padding", {"background-clip": "padding-box"}],
  ["bg-clip-content", {"background-clip": "content-box"}],
  ["bg-clip-text", {"background-clip": "text"}],

  ["bg-transparent", {"background-color": "transparent"}],
  ["bg-current", {"background-color": "currentColor"}],
  ["bg-yellow-200", {"--tw-bg-opacity": "1", "background-color": "rgba(253,230,138,var(--tw-bg-opacity))"}],

  ["bg-opacity-0", {"--tw-bg-opacity": "0"}],
  ["bg-opacity-5", {"--tw-bg-opacity": "0.05"}],
  ["bg-opacity-20",  {"--tw-bg-opacity": "0.2"}],

  ["bg-origin-border", {"background-origin": "border-box"}],
  ["bg-origin-padding", {"background-origin": "padding-box"}],
  ["bg-origin-content", {"background-origin": "content-box"}],

  ["bg-bottom", {"background-position": "bottom"}],
  ["bg-center", {"background-position": "center"}],
  ["bg-left", {"background-position": "left"}],
  ["bg-left-bottom", {"background-position": "left bottom"}],
  ["bg-left-top", {"background-position": "left top"}],
  ["bg-right", {"background-position": "right"}],
  ["bg-right-bottom", {"background-position": "right bottom"}],
  ["bg-right-top", {"background-position": "right top"}],
  ["bg-top", {"background-position": "top"}],

  ["bg-repeat", {"background-repeat": "repeat"}],
  ["bg-no-repeat", {"background-repeat": "no-repeat"}],
  ["bg-repeat-x", {"background-repeat": "repeat-x"}],
  ["bg-repeat-y", {"background-repeat": "repeat-y"}],
  ["bg-repeat-round", {"background-repeat": "round"}],
  ["bg-repeat-space", {"background-repeat": "space"}],

  ["bg-auto", {"background-size": "auto"}],
  ["bg-cover", {"background-size": "cover"}],
  ["bg-contain", {"background-size": "contain"}],

  ["bg-none", {"background-image": "none"}],
  ["bg-gradient-to-t", {"background-image": "linear-gradient(to top, var(--tw-gradient-stops))"}],
  ["bg-gradient-to-tr", {"background-image": "linear-gradient(to top right, var(--tw-gradient-stops))"}],
  ["bg-gradient-to-r", {"background-image": "linear-gradient(to right, var(--tw-gradient-stops))"}],
  ["bg-gradient-to-br", {"background-image": "linear-gradient(to bottom right, var(--tw-gradient-stops))"}],
  ["bg-gradient-to-b", {"background-image": "linear-gradient(to bottom, var(--tw-gradient-stops))"}],
  ["bg-gradient-to-bl", {"background-image": "linear-gradient(to bottom left, var(--tw-gradient-stops))"}],
  ["bg-gradient-to-l", {"background-image": "linear-gradient(to left, var(--tw-gradient-stops))"}],
  ["bg-gradient-to-tl", {"background-image": "linear-gradient(to top left, var(--tw-gradient-stops))"}],

  ["from-transparent", {"--tw-gradient-from": "transparent",
      "--tw-gradient-stops": "var(--tw-gradient-from), var(--tw-gradient-to, rgba(0,0,0,0))"}],
  ["from-current", {"--tw-gradient-from": "currentColor",
      "--tw-gradient-stops": "var(--tw-gradient-from), var(--tw-gradient-to, rgba(255,255,255,0))"}],
  ["from-black", {"--tw-gradient-from": "#000000",
      "--tw-gradient-stops": "var(--tw-gradient-from), var(--tw-gradient-to, rgba(0,0,0,0))"}], 
  ["from-white", {"--tw-gradient-from": "#ffffff",
      "--tw-gradient-stops": "var(--tw-gradient-from), var(--tw-gradient-to, rgba(255,255,255,0))"}], 
  ["from-gray-300", {"--tw-gradient-from": "#D1D5DB",
    "--tw-gradient-stops": "var(--tw-gradient-from), var(--tw-gradient-to, rgba(209,213,219,0))"}],

  ["via-transparent", {"--tw-gradient-stops": "var(--tw-gradient-from), transparent, var(--tw-gradient-to, rgba(0,0,0,0))"}],
  ["via-current", {"--tw-gradient-stops": "var(--tw-gradient-from), currentColor, var(--tw-gradient-to, rgba(255,255,255,0))"}],
  ["via-black", {"--tw-gradient-stops": "var(--tw-gradient-from), #000000, var(--tw-gradient-to, rgba(0,0,0,0))"}],
  ["via-white", {"--tw-gradient-stops": "var(--tw-gradient-from), #ffffff, var(--tw-gradient-to, rgba(255,255,255,0))"}],
  ["via-purple-50", {"--tw-gradient-stops": "var(--tw-gradient-from), #F5F3FF, var(--tw-gradient-to, rgba(245,243,255,0))"}],

  ["to-transparent", {"--tw-gradient-to": "transparent"}],  
  ["to-current",  {"--tw-gradient-to": "currentColor"}], 
  ["to-black", {"--tw-gradient-to": "#000000"}], 
  ["to-white", {"--tw-gradient-to": "#ffffff"}],
  ["to-gray-50", {"--tw-gradient-to": "#F9FAFB"}],

  ["rounded-none", {"border-radius": "0px"}],
  ["rounded-sm", {"border-radius": "0.125rem"}],
  ["rounded", {"border-radius": "0.25rem"}],
  ["rounded-md", {"border-radius": "0.375rem"}],
  ["rounded-lg", {"border-radius": "0.5rem"}],
  ["rounded-xl", {"border-radius": "0.75rem"}],
  ["rounded-2xl", {"border-radius": "1rem"}],
  ["rounded-3xl", {"border-radius": "1.5rem"}],
  ["rounded-full", {"border-radius": "9999px"}],
  ["rounded-t-lg", {"border-top-left-radius": "0.5rem", "border-top-right-radius": "0.5rem"}],
  ["rounded-r-sm", {"border-top-right-radius": "0.125rem", "border-bottom-right-radius": "0.125rem"}],
  ["rounded-b-full", {"border-bottom-right-radius": "9999px", "border-bottom-left-radius": "9999px"}],
  ["rounded-l-2xl", {"border-top-left-radius": "1rem", "border-bottom-left-radius": "1rem"}],
  ["rounded-tl-md", {"border-top-left-radius": "0.375rem"}],
  ["rounded-tr-md", {"border-top-right-radius": "0.375rem"}],
  ["rounded-bl-md", {"border-bottom-left-radius": "0.375rem"}],
  ["rounded-br-md", {"border-bottom-right-radius": "0.375rem"}],

  ["border-0", {"border-width": "0px"}],
  ["border-2", {"border-width": "2px"}],
  ["border-4", {"border-width": "4px"}],
  ["border-8", {"border-width": "8px"}],
  ["border", {"border-width": "1px"}],
  ["border-t-4", {"border-top-width": "4px"}],
  ["border-b", {"border-bottom-width": "1px"}],
  ["border-l-0", {"border-left-width": "0px"}],
  ["border-r-8", {"border-right-width": "8px"}],

  ["border-transparent", {"border-color": "transparent"}],
  ["border-current", {"border-color": "currentColor"}],
  ["border-purple-900", {"--tw-border-opacity": "1", "border-color": "rgba(76,29,149,var(--tw-border-opacity))"}],
  ["border-black", {"--tw-border-opacity": "1", "border-color": "rgba(0,0,0,var(--tw-border-opacity))"}],
  ["border-white", {"--tw-border-opacity": "1", "border-color": "rgba(255,255,255,var(--tw-border-opacity))"}],

  ["border-opacity-0", {"--tw-border-opacity": "0"}],
  ["border-opacity-5", {"--tw-border-opacity": "0.05"}],
  ["border-opacity-100",  {"--tw-border-opacity": "1"}],

  ["border-solid", {"border-style": "solid"}],
  ["border-dashed", {"border-style": "dashed"}],
  ["border-dotted", {"border-style": "dotted"}],
  ["border-double", {"border-style": "double"}],
  ["border-none", {"border-style": "none"}],

  ["divide-x", {"--tw-divide-x-reverse": "0",
    "border-right-width": "calc(1px * var(--tw-divide-x-reverse))", 
    "border-left-width": "calc(1px * calc(1 - var(--tw-divide-x-reverse)))"}],
  ["divide-x-0", {"--tw-divide-x-reverse": "0",
    "border-right-width": "calc(0px * var(--tw-divide-x-reverse))", 
    "border-left-width": "calc(0px * calc(1 - var(--tw-divide-x-reverse)))"}],
  ["divide-x-2", {"--tw-divide-x-reverse": "0",
    "border-right-width": "calc(2px * var(--tw-divide-x-reverse))", 
    "border-left-width": "calc(2px * calc(1 - var(--tw-divide-x-reverse)))"}],
  ["divide-x-4", {"--tw-divide-x-reverse": "0",
    "border-right-width": "calc(4px * var(--tw-divide-x-reverse))", 
    "border-left-width": "calc(4px * calc(1 - var(--tw-divide-x-reverse)))"}],

  ["divide-y", {"--tw-divide-y-reverse": "0",
    "border-bottom-width": "calc(1px * var(--tw-divide-y-reverse))", 
    "border-top-width": "calc(1px * calc(1 - var(--tw-divide-y-reverse)))"}],
  ["divide-y-0", {"--tw-divide-y-reverse": "0",
    "border-bottom-width": "calc(0px * var(--tw-divide-y-reverse))", 
    "border-top-width": "calc(0px * calc(1 - var(--tw-divide-y-reverse)))"}],
  ["divide-y-2", {"--tw-divide-y-reverse": "0",
    "border-bottom-width": "calc(2px * var(--tw-divide-y-reverse))", 
    "border-top-width": "calc(2px * calc(1 - var(--tw-divide-y-reverse)))"}],
  ["divide-y-4", {"--tw-divide-y-reverse": "0",
    "border-bottom-width": "calc(4px * var(--tw-divide-y-reverse))", 
    "border-top-width": "calc(4px * calc(1 - var(--tw-divide-y-reverse)))"}],

  ["divide-transparent", {"border-color": "transparent"}],
  ["divide-current", {"border-color": "currentColor"}],
  ["divide-purple-900", {"--tw-divide-opacity": "1", "border-color": "rgba(76,29,149,var(--tw-divide-opacity))"}],
  ["divide-black", {"--tw-divide-opacity": "1", "border-color": "rgba(0,0,0,var(--tw-divide-opacity))"}],
  ["divide-white", {"--tw-divide-opacity": "1", "border-color": "rgba(255,255,255,var(--tw-divide-opacity))"}],

  ["divide-opacity-0", {"--tw-divide-opacity": "0"}],
  ["divide-opacity-5", {"--tw-divide-opacity": "0.05"}],
  ["divide-opacity-100", {"--tw-divide-opacity": "1"}],

  ["divide-solid", {"border-style": "solid"}],
  ["divide-dashed", {"border-style": "dashed"}],
  ["divide-dotted", {"border-style": "dotted"}],
  ["divide-double", {"border-style": "double"}],
  ["divide-none", {"border-style": "none"}],

  ["ring-0", {"--tw-ring-offset-shadow": "var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color)",
              "--tw-ring-shadow": "var(--tw-ring-inset) 0 0 0 calc(0px + var(--tw-ring-offset-width)) var(--tw-ring-color)",
              "box-shadow": "var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000)"}],
  ["ring-1", {"--tw-ring-offset-shadow": "var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color)",
              "--tw-ring-shadow": "var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color)",
              "box-shadow": "var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000)"}],
  ["ring", {"--tw-ring-offset-shadow": "var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color)",
              "--tw-ring-shadow": "var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color)",
              "box-shadow": "var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000)"}],

  ["ring-inset", {"--tw-ring-inset": "inset"}],

  ["ring-transparent", {"--tw-ring-color": "transparent"}],
  ["ring-current", {"--tw-ring-color": "currentColor"}],
  ["ring-black", {"--tw-ring-color": "rgba(0,0,0,var(--tw-ring-opacity))"}],
  ["ring-white", {"--tw-ring-color": "rgba(255,255,255,var(--tw-ring-opacity))"}],
  ["ring-gray-50", {"--tw-ring-color": "rgba(249,250,251,var(--tw-ring-opacity))"}],

  ["ring-opacity-40", {"--tw-ring-opacity": "0.4"}],

  ["ring-offset-0", {"--tw-ring-offset-width": "0px"}],
  ["ring-offset-1", {"--tw-ring-offset-width": "1px"}],

  ["ring-offset-transparent", {"--tw-ring-offset-color": "transparent"}],
  ["ring-offset-current", {"--tw-ring-offset-color": "currentColor"}],
  ["ring-offset-black", {"--tw-ring-offset-color": "#000000"}],
  ["ring-offset-white", {"--tw-ring-offset-color": "#ffffff"}],
  ["ring-offset-purple-300", {"--tw-ring-offset-color": "#C4B5FD"}],

  ["shadow-sm", {"--tw-shadow": "0 1px 2px 0 rgba(0, 0, 0, 0.05)",
      "box-shadow": "var(--tw-ring-offset-shadow,0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)"}],
  ["shadow", {"--tw-shadow": "0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06)",
      "box-shadow": "var(--tw-ring-offset-shadow,0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)"}],
  ["shadow-md", {"--tw-shadow": "0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06)",
      "box-shadow": "var(--tw-ring-offset-shadow,0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)"}],
  ["shadow-lg", {"--tw-shadow": "0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05)",
      "box-shadow": "var(--tw-ring-offset-shadow,0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)"}],
  ["shadow-xl", {"--tw-shadow": "0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04)",
      "box-shadow": "var(--tw-ring-offset-shadow,0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)"}],
  ["shadow-2xl", {"--tw-shadow": "0 25px 50px -12px rgba(0, 0, 0, 0.25)",
      "box-shadow": "var(--tw-ring-offset-shadow,0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)"}],
  ["shadow-inner", {"--tw-shadow": "inset 0 2px 4px 0 rgba(0, 0, 0, 0.06)",
      "box-shadow": "var(--tw-ring-offset-shadow,0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)"}],
  ["shadow-none", {"--tw-shadow": "0 0 #0000",
      "box-shadow": "var(--tw-ring-offset-shadow,0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)"}],

  ["opacity-0", {"opacity": "0"}],
  ["opacity-5", {"opacity": "0.05"}],
  ["opacity-10", {"opacity": "0.1"}],
  ["opacity-20", {"opacity": "0.2"}],

  ["mix-blend-normal", {"mix-blend-mode": "normal"}],
  ["mix-blend-multiply", {"mix-blend-mode": "multiply"}],
  ["mix-blend-screen", {"mix-blend-mode": "screen"}],
  ["mix-blend-overlay", {"mix-blend-mode": "overlay"}],
  ["mix-blend-darken", {"mix-blend-mode": "darken"}],
  ["mix-blend-lighten", {"mix-blend-mode": "lighten"}],
  ["mix-blend-color-dodge", {"mix-blend-mode": "color-dodge"}],
  ["mix-blend-color-burn", {"mix-blend-mode": "color-burn"}],
  ["mix-blend-hard-light", {"mix-blend-mode": "hard-light"}],
  ["mix-blend-soft-light", {"mix-blend-mode": "soft-light"}],
  ["mix-blend-difference", {"mix-blend-mode": "difference"}],
  ["mix-blend-exclusion", {"mix-blend-mode": "exclusion"}],
  ["mix-blend-hue", {"mix-blend-mode": "hue"}],
  ["mix-blend-saturation", {"mix-blend-mode": "saturation"}],
  ["mix-blend-color", {"mix-blend-mode": "color"}],
  ["mix-blend-luminosity", {"mix-blend-mode": "luminosity"}],

  ["bg-blend-normal", {"background-blend-mode": "normal"}],
  ["bg-blend-multiply", {"background-blend-mode": "multiply"}],
  ["bg-blend-screen", {"background-blend-mode": "screen"}],
  ["bg-blend-overlay", {"background-blend-mode": "overlay"}],
  ["bg-blend-darken", {"background-blend-mode": "darken"}],
  ["bg-blend-lighten", {"background-blend-mode": "lighten"}],
  ["bg-blend-color-dodge", {"background-blend-mode": "color-dodge"}],
  ["bg-blend-color-burn", {"background-blend-mode": "color-burn"}],
  ["bg-blend-hard-light", {"background-blend-mode": "hard-light"}],
  ["bg-blend-soft-light", {"background-blend-mode": "soft-light"}],
  ["bg-blend-difference", {"background-blend-mode": "difference"}],
  ["bg-blend-exclusion", {"background-blend-mode": "exclusion"}],
  ["bg-blend-hue", {"background-blend-mode": "hue"}],
  ["bg-blend-saturation", {"background-blend-mode": "saturation"}],
  ["bg-blend-color", {"background-blend-mode": "color"}],
  ["bg-blend-luminosity", {"background-blend-mode": "luminosity"}],

  ["blur-none", {"--tw-blur": "blur(0)", "filter": "var(--tw-filter)"}],
  ["blur-sm", {"--tw-blur": "blur(4px)", "filter": "var(--tw-filter)"}],
  ["blur", {"--tw-blur": "blur(8px)", "filter": "var(--tw-filter)"}],
  ["blur-md", {"--tw-blur": "blur(12px)", "filter": "var(--tw-filter)"}],
  ["blur-lg", {"--tw-blur": "blur(16px)", "filter": "var(--tw-filter)"}],
  ["blur-xl", {"--tw-blur": "blur(24px)", "filter": "var(--tw-filter)"}],
  ["blur-2xl", {"--tw-blur": "blur(40px)", "filter": "var(--tw-filter)"}],
  ["blur-3xl", {"--tw-blur": "blur(64px)", "filter": "var(--tw-filter)"}],

  ["brightness-0", {"--tw-brightness": "brightness(0)", "filter": "var(--tw-filter)"}],
  ["brightness-50", {"--tw-brightness": "brightness(0.5)", "filter": "var(--tw-filter)"}],

  ["contrast-0", {"--tw-contrast": "contrast(0)", "filter": "var(--tw-filter)"}],
  ["contrast-50", {"--tw-contrast": "contrast(0.5)", "filter": "var(--tw-filter)"}],

  ["drop-shadow-sm", {"--tw-drop-shadow": "drop-shadow(0 1px 1px rgba(0,0,0,0.05))", "filter": "var(--tw-filter)"}],
  ["drop-shadow", {"--tw-drop-shadow": "drop-shadow(0 1px 2px rgba(0, 0, 0, 0.1)) drop-shadow(0 1px 1px rgba(0, 0, 0, 0.06))", "filter": "var(--tw-filter)"}],
  ["drop-shadow-md", {"--tw-drop-shadow": "drop-shadow(0 4px 3px rgba(0, 0, 0, 0.07)) drop-shadow(0 2px 2px rgba(0, 0, 0, 0.06))", "filter": "var(--tw-filter)"}],
  ["drop-shadow-lg", {"--tw-drop-shadow": "drop-shadow(0 10px 8px rgba(0, 0, 0, 0.04)) drop-shadow(0 4px 3px rgba(0, 0, 0, 0.1))", "filter": "var(--tw-filter)"}],
  ["drop-shadow-xl", {"--tw-drop-shadow": "drop-shadow(0 20px 13px rgba(0, 0, 0, 0.03)) drop-shadow(0 8px 5px rgba(0, 0, 0, 0.08))", "filter": "var(--tw-filter)"}],
  ["drop-shadow-2xl", {"--tw-drop-shadow": "drop-shadow(0 25px 25px rgba(0, 0, 0, 0.15))", "filter": "var(--tw-filter)"}],
  ["drop-shadow-none", {"--tw-drop-shadow": "drop-shadow(0 0 #0000)", "filter": "var(--tw-filter)"}],

  ["grayscale-0", {"--tw-grayscale": "grayscale(0)", "filter": "var(--tw-filter)"}],
  ["grayscale", {"--tw-grayscale": "grayscale(1)", "filter": "var(--tw-filter)"}],

  ["hue-rotate-0", {"--tw-hue-rotate": "hue-rotate(0deg)", "filter": "var(--tw-filter)"}],
  ["hue-rotate-90", {"--tw-hue-rotate": "hue-rotate(90deg)", "filter": "var(--tw-filter)"}],
  ["-hue-rotate-90", {"--tw-hue-rotate": "hue-rotate(-90deg)", "filter": "var(--tw-filter)"}],

  ["invert-0", {"--tw-invert": "invert(0)", "filter": "var(--tw-filter)"}],
  ["invert", {"--tw-invert": "invert(1)", "filter": "var(--tw-filter)"}],

  ["saturate-0", {"--tw-saturate": "saturate(0)", "filter": "var(--tw-filter)"}],
  ["saturate-50", {"--tw-saturate": "saturate(0.5)", "filter": "var(--tw-filter)"}],

  ["sepia-0", {"--tw-sepia": "sepia(0)", "filter": "var(--tw-filter)"}],
  ["sepia", {"--tw-sepia": "sepia(1)", "filter": "var(--tw-filter)"}],

  ["backdrop-blur-none", {"--tw-backdrop-blur": "blur(0)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-blur-sm", {"--tw-backdrop-blur": "blur(4px)", "backdrop-filter": "var(--tw-backdrop-filter)"}],

  ["backdrop-brightness-0", {"--tw-backdrop-brightness": "brightness(0)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-brightness-50", {"--tw-backdrop-brightness": "brightness(0.5)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  
  ["backdrop-contrast-0", {"--tw-backdrop-contrast": "contrast(0)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-contrast-50", {"--tw-backdrop-contrast": "contrast(0.5)", "backdrop-filter": "var(--tw-backdrop-filter)"}],

  ["backdrop-grayscale-0", {"--tw-backdrop-grayscale": "grayscale(0)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-grayscale", {"--tw-backdrop-grayscale": "grayscale(1)", "backdrop-filter": "var(--tw-backdrop-filter)"}],

  ["backdrop-hue-rotate-0", {"--tw-backdrop-hue-rotate": "hue-rotate(0deg)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-hue-rotate-90", {"--tw-backdrop-hue-rotate": "hue-rotate(90deg)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["-backdrop-hue-rotate-90", {"--tw-backdrop-hue-rotate": "hue-rotate(-90deg)", "backdrop-filter": "var(--tw-backdrop-filter)"}],

  ["backdrop-invert-0", {"--tw-backdrop-invert": "invert(0)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-invert", {"--tw-backdrop-invert": "invert(1)", "backdrop-filter": "var(--tw-backdrop-filter)"}],

  ["backdrop-opacity-0", {"--tw-backdrop-opacity": "opacity(0)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-opacity-50", {"--tw-backdrop-opacity": "opacity(0.5)", "backdrop-filter": "var(--tw-backdrop-filter)"}],

  ["backdrop-saturate-0", {"--tw-backdrop-saturate": "saturate(0)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-saturate-50", {"--tw-backdrop-saturate": "saturate(0.5)", "backdrop-filter": "var(--tw-backdrop-filter)"}],

  ["backdrop-sepia-0", {"--tw-backdrop-sepia": "sepia(0)", "backdrop-filter": "var(--tw-backdrop-filter)"}],
  ["backdrop-sepia", {"--tw-backdrop-sepia": "sepia(1)", "backdrop-filter": "var(--tw-backdrop-filter)"}],

  ["border-collapse", {"border-collapse": "collapse"}],
  ["border-separate", {"border-collapse": "separate"}],

  ["table-auto", {"table-layout": "auto"}],
  ["table-fixed", {"table-layout": "fixed"}],

  ["transition-none", {"transition-property": "none", 
    "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)", "transition-duration": "150ms"}],
  ["transition-all", {"transition-property": "all", 
    "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)", "transition-duration": "150ms"}],
  ["transition", {"transition-property": "background-color, border-color, color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter", 
    "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)", "transition-duration": "150ms"}],
  ["transition-colors", {"transition-property": "background-color, border-color, color, fill, stroke", 
    "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)", "transition-duration": "150ms"}],
  ["transition-opacity", {"transition-property": "opacity", 
    "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)", "transition-duration": "150ms"}],
  ["transition-shadow", {"transition-property": "box-shadow", 
    "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)", "transition-duration": "150ms"}],
  ["transition-transform", {"transition-property": "transform", 
    "transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)", "transition-duration": "150ms"}],
    
  ["duration-500", {"transition-duration": "500ms"}],
  ["duration-700", {"transition-duration": "700ms"}],
  ["duration-1000", {"transition-duration": "1000ms"}],

  ["ease-linear", {"transition-timing-function": "linear"}],
  ["ease-in", {"transition-timing-function": "cubic-bezier(0.4, 0, 1, 1)"}],
  ["ease-out",  {"transition-timing-function": "cubic-bezier(0, 0, 0.2, 1)"}],
  ["ease-in-out", {"transition-timing-function": "cubic-bezier(0.4, 0, 0.2, 1)"}],

  ["delay-500", {"transition-delay": "500ms"}],
  ["delay-700", {"transition-delay": "700ms"}],
  ["delay-1000", {"transition-delay": "1000ms"}],

  ["animate-none", {"animation": "none"}],
  ["animate-spin", {"animation": "spin 1s linear infinite"}],
  ["animate-ping", {"animation": "ping 1s cubic-bezier(0, 0, 0.2, 1) infinite"}],
  ["animate-pulse", {"animation": "pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite"}],
  ["animate-bounce", {"animation": "bounce 1s infinite"}],

  ["transform-gpu", {"--tw-transform": "translate3d(var(--tw-translate-x), var(--tw-translate-y), 0) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))"}],

  ["origin-center", {"transform-origin": "center"}],
  ["origin-top",  {"transform-origin": "top"}],
  ["origin-top-right", {"transform-origin": "top right"}],
  ["origin-right", {"transform-origin": "right"}],
  ["origin-bottom-right", {"transform-origin": "bottom right"}],
  ["origin-bottom", {"transform-origin": "bottom"}],
  ["origin-bottom-left", {"transform-origin": "bottom left"}],
  ["origin-left", {"transform-origin": "left"}],
  ["origin-top-left", {"transform-origin": "top left"}],

  ["scale-90", {"--tw-scale-x": "0.9", "--tw-scale-y": "0.9", "transform": "var(--tw-transform)"}],
  ["scale-x-110", {"--tw-scale-x": "1.1", "transform": "var(--tw-transform)"}],
  ["scale-y-50", {"--tw-scale-y": "0.5", "transform": "var(--tw-transform)"}],

  ["rotate-12", {"--tw-rotate": "12deg", "transform": "var(--tw-transform)"}],
  ["-rotate-12", {"--tw-rotate": "-12deg", "transform": "var(--tw-transform)"}],

  ["translate-x-1.5", {"--tw-translate-x": "0.375rem", "transform": "var(--tw-transform)"}],
  ["translate-x-1/2", {"--tw-translate-x": "50%", "transform": "var(--tw-transform)"}],
  ["-translate-x-1.5", {"--tw-translate-x": "-0.375rem", "transform": "var(--tw-transform)"}],
  ["-translate-x-1/2", {"--tw-translate-x": "-50%", "transform": "var(--tw-transform)"}],
  ["translate-x-full", {"--tw-translate-x": "100%", "transform": "var(--tw-transform)"}],
  ["-translate-x-full", {"--tw-translate-x": "-100%", "transform": "var(--tw-transform)"}],

  ["translate-y-1.5", {"--tw-translate-y": "0.375rem", "transform": "var(--tw-transform)"}],
  ["translate-y-1/2", {"--tw-translate-y": "50%", "transform": "var(--tw-transform)"}],
  ["-translate-y-1.5", {"--tw-translate-y": "-0.375rem", "transform": "var(--tw-transform)"}],
  ["-translate-y-1/2", {"--tw-translate-y": "-50%", "transform": "var(--tw-transform)"}],
  ["translate-y-full", {"--tw-translate-y": "100%", "transform": "var(--tw-transform)"}],
  ["-translate-y-full", {"--tw-translate-y": "-100%", "transform": "var(--tw-transform)"}],

  ["skew-x-12", {"--tw-skew-x": "12deg", "transform": "var(--tw-transform)"}],
  ["-skew-x-12", {"--tw-skew-x": "-12deg", "transform": "var(--tw-transform)"}],

  ["appearance-none", {"appearance": "none"}],

  ["cursor-auto", {"cursor": "auto"}],
  ["cursor-default", {"cursor": "default"}],
  ["cursor-pointer", {"cursor": "pointer"}],
  ["cursor-wait", {"cursor": "wait"}],
  ["cursor-text", {"cursor": "text"}],
  ["cursor-move", {"cursor": "move"}],
  ["cursor-help", {"cursor": "help"}],
  ["cursor-not-allowed", {"cursor": "not-allowed"}],

  ["outline-none", {"outline": "2px solid transparent", "outline-offset": "2px"}],
  ["outline-white", {"outline": "2px dotted white", "outline-offset": "2px"}],
  ["outline-black", {"outline": "2px dotted black", "outline-offset": "2px"}],

  ["pointer-events-none", {"pointer-events": "none"}],
  ["pointer-events-auto", {"pointer-events": "auto"}],

  ["resize-none", {"resize": "none"}],
  ["resize-y", {"resize": "vertical"}],
  ["resize-x", {"resize": "horizontal"}],
  ["resize", {"resize": "both"}],

  ["select-none", {"user-select": "none"}],
  ["select-text", {"user-select": "text"}],
  ["select-all",  {"user-select": "all"}],
  ["select-auto", {"user-select": "auto"}],

  ["fill-current", {"fill": "currentColor"}],
  ["stroke-current", {"stroke": "currentColor"}],
  ["stroke-0", {"stroke-width": "0"}],
  ["stroke-1", {"stroke-width": "1"}],
  ["stroke-2", {"stroke-width": "2"}],

  ["sr-only", {"position": "absolute", "width": "1px", "height": "1px", "padding": "0",
    "margin": "-1px", "overflow": "hidden", "clip": "rect(0, 0, 0, 0)", "white-space": "nowrap",
    "border-width": "0"}],

  ["not-sr-only", {"position": "static", "width": "auto", "height": "auto", "padding": "0",
    "margin": "0", "overflow": "visible", "clip": "auto", "white-space": "normal"}],

  ["xxxx", false],
  ["", false],
  ["-", false],
  ["!", false],
]

var ntests = tests.length;
for (var i=0; i<ntests;i++) {
  var t = tests[i]
  var n = compile(t[0])
  var expected = t[1]
  var got = n.props

  if (!expected) {
    if (expected !== n) {
      console.log("Test Failed!!! - " + t[0])
      console.log(n)
      continue;
    }
  }

  if (!n && expected) {
    console.log("Test Failed!!! - " + t[0])
    console.log(n)
    continue;
  }

  for (const [key, value] of Object.entries(expected)) {
    if (key.startsWith("_")) {
      var key2 = key.substring(1)
      if (n[key2] != value) {
        console.log("Test Failed!!! - " + t[0])
        console.log(n)
      }
    }
    else if (got[key] != value) {
      console.log("Test Failed!!! - " + t[0])
      console.log(got)
    }
  }
}

console.log(`Processed ${ntests} tests`);